@@ -1,7 +1,7 @@
 package Pod::Weaver::PluginBundle::Author::GETTY;
 our $AUTHORITY = 'cpan:GETTY';
 # ABSTRACT: GETTY's default Pod::Weaver config
-$Pod::Weaver::PluginBundle::Author::GETTY::VERSION = '0.117';
+$Pod::Weaver::PluginBundle::Author::GETTY::VERSION = '0.120';
 use strict;
 use warnings;
 
@@ -12,16 +12,15 @@ sub _exp { Pod::Weaver::Config::Assembler->expand_package($_[0]) }
 sub mvp_bundle_config {
   my @plugins;
   push @plugins, (
-    [ '@GETTY/CorePrep',    _exp('@CorePrep'), {} ],
-    [ '@GETTY/Encoding',    _exp('-Encoding'), { encoding => 'UTF-8' } ],
-    [ '@GETTY/Name',        _exp('Name'),      {} ],
-    [ '@GETTY/Version',     _exp('Version'),   {} ],
+    [ '@GETTY/CorePrep',       _exp('@CorePrep'), {} ],
+    [ '@GETTY/SingleEncoding', _exp('-SingleEncoding'), {} ],
+    [ '@GETTY/Name',           _exp('Name'),      {} ],
+    [ '@GETTY/Version',        _exp('Version'),   {} ],
 
     [ '@GETTY/Prelude',     _exp('Region'),  { region_name => 'prelude'     } ],
     [ '@GETTY/Synopsis',    _exp('Generic'), { header      => 'SYNOPSIS'    } ],
     [ '@GETTY/Description', _exp('Generic'), { header      => 'DESCRIPTION' } ],
     [ '@GETTY/Overview',    _exp('Generic'), { header      => 'OVERVIEW'    } ],
-
     [ '@GETTY/Stability',   _exp('Generic'), { header      => 'STABILITY'   } ],
   );
 
@@ -66,7 +65,7 @@ Pod::Weaver::PluginBundle::Author::GETTY - GETTY's default Pod::Weaver config
 
 =head1 VERSION
 
-version 0.117
+version 0.120
 
 =head1 DESCRIPTION
 
